==> haskell-cipher-aes128-0.7.0.3-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes128
version: 0.7.0.3
id: cipher-aes128-0.7.0.3-Ejqf5GqoGyXDPeh4UB2Az1
key: cipher-aes128-0.7.0.3-Ejqf5GqoGyXDPeh4UB2Az1
license: BSD-3-Clause
copyright: Thomas M. DuBuisson
maintainer: thomas.dubuisson@gmail.com
author: Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage: https://github.com/TomMD/cipher-aes128
synopsis: AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.
category: Cryptography
abi: f20f3c394b806f6d07ecbfe431390ec7
exposed: True
exposed-modules:
    Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes128-0.7.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes128-0.7.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cipher-aes128-0.7.0.3
hs-libraries: HScipher-aes128-0.7.0.3-Ejqf5GqoGyXDPeh4UB2Az1
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU
    tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             crypto-api-0.13.3-F192MK1lmj0HbgPoMEH6qU=6900b771227d4e4da26f3f5981befd1d
             tagged-0.8.5-8zhZJ4AR6AIK89q9NUJ4H=a77bb2a04ac30650821b1fe6972fa094
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
haddock-interfaces: /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cipher-aes128-0.7.0.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-cipher-aes128.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cipher-aes128
version: 0.7.0.3
id: cipher-aes128-0.7.0.3-1yQsnzuJBsh9H6rqUKKhzx
key: cipher-aes128-0.7.0.3-1yQsnzuJBsh9H6rqUKKhzx
license: BSD-3-Clause
copyright: Thomas M. DuBuisson
maintainer: thomas.dubuisson@gmail.com
author: Thomas M. DuBuisson, Vincent Hanquez (See AUTHORS file)
homepage: https://github.com/TomMD/cipher-aes128
synopsis: AES and common modes using AES-NI when available.
description:
    Cipher-aes128 is an implementation of AES and common modes of operation.  It borrows Hanquez'\''s C AES code (see '\''cipher-aes'\'') but
    is unique due to including compile-time detection of
    NI compiler support, a slightly more functional interface
    for GCM operations, exposure of '\''Ptr'\'' based operations via the .Internal module, and build-in crypto-api support.
    Cipher-aes128 was originally developed as "'\''cipher-aes'\'' plus trampolines", which has since been adopted into cipher-aes.
category: Cryptography
abi: 27077822fa91efcddcc40b39fc556293
exposed: True
exposed-modules:
    Crypto.Cipher.AES128 Crypto.Cipher.AES128.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes128-0.7.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/cipher-aes128-0.7.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/cipher-aes128-0.7.0.3
hs-libraries: HScipher-aes128-0.7.0.3-1yQsnzuJBsh9H6rqUKKhzx
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             crypto-api-0.13.3-8kwytB5sSk41kEhPI2rwwJ=ce10e49cbca1b74596de9d427ce328a8
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             cereal-0.5.5.0-GXs0HkZKyWNA7Krg63fmZj=2b6502a041f954555a854231cf10da34
haddock-interfaces: /usr/share/doc/haskell-cipher-aes128/html/cipher-aes128.haddock
haddock-html: /usr/share/doc/haskell-cipher-aes128/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
